#[non_exhaustive]pub struct SendCommandInput {
pub session_token: Option<String>,
pub start_session: Option<StartSessionRequest>,
pub start_transaction: Option<StartTransactionRequest>,
pub end_session: Option<EndSessionRequest>,
pub commit_transaction: Option<CommitTransactionRequest>,
pub abort_transaction: Option<AbortTransactionRequest>,
pub execute_statement: Option<ExecuteStatementRequest>,
pub fetch_page: Option<FetchPageRequest>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_token: Option<String>Specifies the session token for the current command. A session token is constant throughout the life of the session.
To obtain a session token, run the StartSession command. This SessionToken is required for every subsequent command that is issued during the current session.
start_session: Option<StartSessionRequest>Command to start a new session. A session token is obtained as part of the response.
start_transaction: Option<StartTransactionRequest>Command to start a new transaction.
end_session: Option<EndSessionRequest>Command to end the current session.
commit_transaction: Option<CommitTransactionRequest>Command to commit the specified transaction.
abort_transaction: Option<AbortTransactionRequest>Command to abort the current transaction.
execute_statement: Option<ExecuteStatementRequest>Command to execute a statement in the specified transaction.
fetch_page: Option<FetchPageRequest>Command to fetch a page.
Implementations
Sourceimpl SendCommandInput
impl SendCommandInput
Sourcepub fn session_token(&self) -> Option<&str>
pub fn session_token(&self) -> Option<&str>
Specifies the session token for the current command. A session token is constant throughout the life of the session.
To obtain a session token, run the StartSession command. This SessionToken is required for every subsequent command that is issued during the current session.
Sourcepub fn start_session(&self) -> Option<&StartSessionRequest>
pub fn start_session(&self) -> Option<&StartSessionRequest>
Command to start a new session. A session token is obtained as part of the response.
Sourcepub fn start_transaction(&self) -> Option<&StartTransactionRequest>
pub fn start_transaction(&self) -> Option<&StartTransactionRequest>
Command to start a new transaction.
Sourcepub fn end_session(&self) -> Option<&EndSessionRequest>
pub fn end_session(&self) -> Option<&EndSessionRequest>
Command to end the current session.
Sourcepub fn commit_transaction(&self) -> Option<&CommitTransactionRequest>
pub fn commit_transaction(&self) -> Option<&CommitTransactionRequest>
Command to commit the specified transaction.
Sourcepub fn abort_transaction(&self) -> Option<&AbortTransactionRequest>
pub fn abort_transaction(&self) -> Option<&AbortTransactionRequest>
Command to abort the current transaction.
Sourcepub fn execute_statement(&self) -> Option<&ExecuteStatementRequest>
pub fn execute_statement(&self) -> Option<&ExecuteStatementRequest>
Command to execute a statement in the specified transaction.
Sourcepub fn fetch_page(&self) -> Option<&FetchPageRequest>
pub fn fetch_page(&self) -> Option<&FetchPageRequest>
Command to fetch a page.
Sourceimpl SendCommandInput
impl SendCommandInput
Sourcepub fn builder() -> SendCommandInputBuilder
pub fn builder() -> SendCommandInputBuilder
Creates a new builder-style object to manufacture SendCommandInput.